@@ -14,7 +14,7 @@ Usage::
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING, overload
+from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_docdb.paginator import (
     DescribeDBClustersPaginator,
@@ -79,51 +79,51 @@ __all__ = ("DocDBClient",)
 
 
 class Exceptions:
-    AuthorizationNotFoundFault: Boto3ClientError
-    CertificateNotFoundFault: Boto3ClientError
-    ClientError: Boto3ClientError
-    DBClusterAlreadyExistsFault: Boto3ClientError
-    DBClusterNotFoundFault: Boto3ClientError
-    DBClusterParameterGroupNotFoundFault: Boto3ClientError
-    DBClusterQuotaExceededFault: Boto3ClientError
-    DBClusterSnapshotAlreadyExistsFault: Boto3ClientError
-    DBClusterSnapshotNotFoundFault: Boto3ClientError
-    DBInstanceAlreadyExistsFault: Boto3ClientError
-    DBInstanceNotFoundFault: Boto3ClientError
-    DBParameterGroupAlreadyExistsFault: Boto3ClientError
-    DBParameterGroupNotFoundFault: Boto3ClientError
-    DBParameterGroupQuotaExceededFault: Boto3ClientError
-    DBSecurityGroupNotFoundFault: Boto3ClientError
-    DBSnapshotAlreadyExistsFault: Boto3ClientError
-    DBSnapshotNotFoundFault: Boto3ClientError
-    DBSubnetGroupAlreadyExistsFault: Boto3ClientError
-    DBSubnetGroupDoesNotCoverEnoughAZs: Boto3ClientError
-    DBSubnetGroupNotFoundFault: Boto3ClientError
-    DBSubnetGroupQuotaExceededFault: Boto3ClientError
-    DBSubnetQuotaExceededFault: Boto3ClientError
-    DBUpgradeDependencyFailureFault: Boto3ClientError
-    InstanceQuotaExceededFault: Boto3ClientError
-    InsufficientDBClusterCapacityFault: Boto3ClientError
-    InsufficientDBInstanceCapacityFault: Boto3ClientError
-    InsufficientStorageClusterCapacityFault: Boto3ClientError
-    InvalidDBClusterSnapshotStateFault: Boto3ClientError
-    InvalidDBClusterStateFault: Boto3ClientError
-    InvalidDBInstanceStateFault: Boto3ClientError
-    InvalidDBParameterGroupStateFault: Boto3ClientError
-    InvalidDBSecurityGroupStateFault: Boto3ClientError
-    InvalidDBSnapshotStateFault: Boto3ClientError
-    InvalidDBSubnetGroupStateFault: Boto3ClientError
-    InvalidDBSubnetStateFault: Boto3ClientError
-    InvalidRestoreFault: Boto3ClientError
-    InvalidSubnet: Boto3ClientError
-    InvalidVPCNetworkStateFault: Boto3ClientError
-    KMSKeyNotAccessibleFault: Boto3ClientError
-    ResourceNotFoundFault: Boto3ClientError
-    SharedSnapshotQuotaExceededFault: Boto3ClientError
-    SnapshotQuotaExceededFault: Boto3ClientError
-    StorageQuotaExceededFault: Boto3ClientError
-    StorageTypeNotSupportedFault: Boto3ClientError
-    SubnetAlreadyInUse: Boto3ClientError
+    AuthorizationNotFoundFault: Type[Boto3ClientError]
+    CertificateNotFoundFault: Type[Boto3ClientError]
+    ClientError: Type[Boto3ClientError]
+    DBClusterAlreadyExistsFault: Type[Boto3ClientError]
+    DBClusterNotFoundFault: Type[Boto3ClientError]
+    DBClusterParameterGroupNotFoundFault: Type[Boto3ClientError]
+    DBClusterQuotaExceededFault: Type[Boto3ClientError]
+    DBClusterSnapshotAlreadyExistsFault: Type[Boto3ClientError]
+    DBClusterSnapshotNotFoundFault: Type[Boto3ClientError]
+    DBInstanceAlreadyExistsFault: Type[Boto3ClientError]
+    DBInstanceNotFoundFault: Type[Boto3ClientError]
+    DBParameterGroupAlreadyExistsFault: Type[Boto3ClientError]
+    DBParameterGroupNotFoundFault: Type[Boto3ClientError]
+    DBParameterGroupQuotaExceededFault: Type[Boto3ClientError]
+    DBSecurityGroupNotFoundFault: Type[Boto3ClientError]
+    DBSnapshotAlreadyExistsFault: Type[Boto3ClientError]
+    DBSnapshotNotFoundFault: Type[Boto3ClientError]
+    DBSubnetGroupAlreadyExistsFault: Type[Boto3ClientError]
+    DBSubnetGroupDoesNotCoverEnoughAZs: Type[Boto3ClientError]
+    DBSubnetGroupNotFoundFault: Type[Boto3ClientError]
+    DBSubnetGroupQuotaExceededFault: Type[Boto3ClientError]
+    DBSubnetQuotaExceededFault: Type[Boto3ClientError]
+    DBUpgradeDependencyFailureFault: Type[Boto3ClientError]
+    InstanceQuotaExceededFault: Type[Boto3ClientError]
+    InsufficientDBClusterCapacityFault: Type[Boto3ClientError]
+    InsufficientDBInstanceCapacityFault: Type[Boto3ClientError]
+    InsufficientStorageClusterCapacityFault: Type[Boto3ClientError]
+    InvalidDBClusterSnapshotStateFault: Type[Boto3ClientError]
+    InvalidDBClusterStateFault: Type[Boto3ClientError]
+    InvalidDBInstanceStateFault: Type[Boto3ClientError]
+    InvalidDBParameterGroupStateFault: Type[Boto3ClientError]
+    InvalidDBSecurityGroupStateFault: Type[Boto3ClientError]
+    InvalidDBSnapshotStateFault: Type[Boto3ClientError]
+    InvalidDBSubnetGroupStateFault: Type[Boto3ClientError]
+    InvalidDBSubnetStateFault: Type[Boto3ClientError]
+    InvalidRestoreFault: Type[Boto3ClientError]
+    InvalidSubnet: Type[Boto3ClientError]
+    InvalidVPCNetworkStateFault: Type[Boto3ClientError]
+    KMSKeyNotAccessibleFault: Type[Boto3ClientError]
+    ResourceNotFoundFault: Type[Boto3ClientError]
+    SharedSnapshotQuotaExceededFault: Type[Boto3ClientError]
+    SnapshotQuotaExceededFault: Type[Boto3ClientError]
+    StorageQuotaExceededFault: Type[Boto3ClientError]
+    StorageTypeNotSupportedFault: Type[Boto3ClientError]
+    SubnetAlreadyInUse: Type[Boto3ClientError]
 
 
 class DocDBClient:
